==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Block/InsertBlock/ts/InsertBlock_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+107"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotacija:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Rotiraj blok&lt;br&gt;za ta kot</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Razmerje X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Povečaj blok v smeri X&lt;br&gt;za ta faktor</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Povečaj blok v smeri Y&lt;br&gt;za ta faktor</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Ohrani razmerja</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Zrcali blok&lt;br&gt;po vodoravni osi</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Zrcali blok&lt;br&gt;po navpični osi</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Vstavi blok</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Block/InsertBlock/ts/InsertBlock_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotacija:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Rotiraj blok&lt;br&gt;za ta kot</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Razmerje X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Povečaj blok v smeri X&lt;br&gt;za ta faktor</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Povečaj blok v smeri Y&lt;br&gt;za ta faktor</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Ohrani razmerja</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Zrcali blok&lt;br&gt;po vodoravni osi</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Zrcali blok&lt;br&gt;po navpični osi</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation>En blok</translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation>Tabela blokov</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Vstavi blok</translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>Stolpci:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>Vrstice:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>Razmak stolpcev:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>Razmak vrstic:</translation>
    </message>
</context>
</TS>
